//@line 36 "/builds/releases/3.1b1/mozilla-central/l10n/fr/browser/firefox-l10n.js"

//@line 38 "/builds/releases/3.1b1/mozilla-central/l10n/fr/browser/firefox-l10n.js"

pref("general.useragent.locale", "fr");
